#!/bin/sh
echo "Starting CubeSQL installation..."

# execute common part
INSTALL_DIR=/opt/cubesql

# process argument
SKIP_STARTUP=0
if [ "$1" = "-skip_startup" ]; then
    SKIP_STARTUP=1
fi

# check if installation folder exists
if [ -d  $INSTALL_DIR ]; then
	# stop server
	sudo killall -q -TERM 'cubesql'
	sleep 5
fi

#remove old installation folder (if exists)
sudo rm -Rdf $INSTALL_DIR

# create new installation folder
sudo mkdir -p $INSTALL_DIR

# copy from data to $INSTALL_DIR
sudo cp -fR ./data/* $INSTALL_DIR
sudo chown root:root "$INSTALL_DIR"
sudo chmod +x "$INSTALL_DIR/cubesql"

# install cubesqlctl
sudo cp ./data/cubesqlctl "/usr/local/bin"
sudo chmod +x "/usr/local/bin/cubesqlctl"
sudo chown root:root "/usr/local/bin/cubesqlctl"

echo "CubeSQL has been successfully installed from your system."

# check if startup script installation must be skipped
if [ $SKIP_STARTUP = 1 ]; then
	echo "No startup script installed."
	return 0
fi

# determine init system (can be systemd or upstart)
INIT_SYSTEM=`(ps -p1 | grep -q systemd && echo systemd || echo upstart)`

if [ $INIT_SYSTEM = "systemd" ]; then
	# Ubuntu >= 15.04
	
	sudo cp ./data/cubesql.service /etc/systemd/system
	sudo chown root:root /etc/systemd/system/cubesql.service
	
	echo "systemd startup script installed."
	echo "To start CubeSQL type: sudo systemctl start cubesql.service"
	return 0
fi

if [ $INIT_SYSTEM = "upstart" ]; then
	# Ubuntu < 15.04
	
	# MUST be root:root
	# some distributions doesn't have the rc.d subdirectory
	INIT_DIR=/etc/rc.d/init.d
	if ! [ -d  $INIT_DIR ]; then
		INIT_DIR=/etc/init.d
	fi

	STARTUP_DIR=/etc/rc.d
	if ! [ -d  $STARTUP_DIR ]; then
		STARTUP_DIR=/etc
	fi

	sudo cp ./data/cubesql.startup "$INIT_DIR/cubesql"
	sudo chown root:root "$INIT_DIR/cubesql"

	# to make the script be run on machine start up we need to create a symbolic link to it
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc2.d/S86cubesql"
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc3.d/S86cubesql"
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc5.d/S86cubesql"

	# now the links to make cubesql shut down
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc0.d/K86cubesql"
	# sudo ln -fs "$INIT_DIR/cubesql" "$STARTUP_DIR/rc6.d/K86cubesql"

	sudo update-rc.d -f cubesql remove
	sudo update-rc.d -f cubesql defaults

	sudo update-rc.d -f cubesql start 10 2 3 4 5 . stop 90 0 1 6 .
	# or chkconfig --add cubesql
	
	echo "upstart startup script installed."
	echo "To start CubeSQL type: sudo cubesqlctl start"
	return 0
fi

echo "Init system not recognized (no systemd or upstart found)."
echo "CubeSQL has been installed but it will not automatically start."
return 1
